pub struct Renderer {
pub quad_commands: Vec<QuadCommand>,
pub text_commands: Vec<TextCommand>,
pub text_measures: Vec<Vec<f32>>,
pub overlay_quad_commands: Vec<QuadCommand>,
pub overlay_text_commands: Vec<TextCommand>,
/* private fields */
}Fields
quad_commands: Vec<QuadCommand>text_commands: Vec<TextCommand>text_measures: Vec<Vec<f32>>Pixel widths measured by the render layer (indexed by TextCommand index).
Each entry corresponds to measure_chars of the same TextCommand.
overlay_quad_commands: Vec<QuadCommand>Overlay commands drawn on top of everything (for dropdowns, tooltips, etc.)
overlay_text_commands: Vec<TextCommand>Implementations
Sourceimpl Renderer
impl Renderer
pub fn new() -> Self
pub fn clear(&mut self)
Sourcepub fn overlay_fill_rect_styled(
&mut self,
rect: (f32, f32, f32, f32),
color: [f32; 4],
border_radius: f32,
border_width: f32,
border_color: [f32; 4],
)
pub fn overlay_fill_rect_styled( &mut self, rect: (f32, f32, f32, f32), color: [f32; 4], border_radius: f32, border_width: f32, border_color: [f32; 4], )
Push a quad command to the overlay layer (drawn on top of everything).
Sourcepub fn overlay_draw_text(
&mut self,
text: &str,
pos: (f32, f32),
color: [u8; 3],
bounds: (f32, f32),
metrics: Metrics,
align: Align,
)
pub fn overlay_draw_text( &mut self, text: &str, pos: (f32, f32), color: [u8; 3], bounds: (f32, f32), metrics: Metrics, align: Align, )
Push a text command to the overlay layer (drawn on top of everything).
Sourcepub fn overlay_draw_text_with_font(
&mut self,
text: &str,
pos: (f32, f32),
color: [u8; 3],
bounds: (f32, f32),
metrics: Metrics,
align: Align,
font_family: &str,
)
pub fn overlay_draw_text_with_font( &mut self, text: &str, pos: (f32, f32), color: [u8; 3], bounds: (f32, f32), metrics: Metrics, align: Align, font_family: &str, )
Push a text command with font to the overlay layer.
pub fn push_clip(&mut self, clip: ClipRect)
pub fn pop_clip(&mut self)
pub fn fill_rect(&mut self, rect: (f32, f32, f32, f32), color: [f32; 3])
pub fn fill_rect_rounded( &mut self, rect: (f32, f32, f32, f32), color: [f32; 4], border_radius: f32, )
pub fn fill_rect_styled( &mut self, rect: (f32, f32, f32, f32), color: [f32; 4], border_radius: f32, border_width: f32, border_color: [f32; 4], )
pub fn draw_text( &mut self, text: &str, pos: (f32, f32), color: [u8; 3], bounds: (f32, f32), metrics: Metrics, align: Align, )
pub fn draw_text_with_font( &mut self, text: &str, pos: (f32, f32), color: [u8; 3], bounds: (f32, f32), metrics: Metrics, align: Align, font_family: &str, )
pub fn draw_text_measured( &mut self, text: &str, pos: (f32, f32), color: [u8; 3], bounds: (f32, f32), metrics: Metrics, align: Align, measure_chars: Vec<usize>, ) -> usize